#!/usr/bin/python3
# 3/28/2019 Skeetzo
# onlysnarf.py menu system

### doesn't work:
# upload & backup (requires upload via local added to main script)
# settings menu -> "Incorrect Index"

import random
import os
import shutil
import datetime
import json
import sys
import pathlib
from OnlySnarf.settings import SETTINGS as settings
from OnlySnarf import onlysnarf
 
###################
##### Globals #####
###################

version = "1.1.6"
header = "\n ________         .__          _________                     _____ \n \
\\_____  \\   ____ |  | ___.__./   _____/ ____ _____ ________/ ____\\\n \
 /   |   \\ /    \\|  |<   |  |\\_____  \\ /    \\\\__  \\\\_   _ \\   __\\ \n \
/    |    \\   |  \\  |_\\___  |/        \\   |  \\/ __ \\ |  |\\/| |   \n \
\\_______  /___|  /____/ ____/_______  /___|  (____  \\\\__|  |_|   \n \
        \\/     \\/     \\/            \\/     \\/     \\/              \n"

UPDATED = False
UPDATED_TO = False
INITIALIZED = False

colors = {
        'blue': '\033[94m',
        'header': '\033[48;1;34m',
        'teal': '\033[96m',
        'pink': '\033[95m',
        'green': '\033[92m',
        'yellow': '\033[93m',
        'menu': '\033[48;1;44m'
        }

# Main Menu
menuItems = [
    [ "Actions", "action"],
    [ "Settings", "set_settings"],
    [ "Exit", "exit"]
]

# Actions Menu
actionItems = sorted([
    [ "Test", ["test"]],
    [ "Release", ["release"]],
    [ "Download", ["download"]],
    # [ "Upload", ["upload"]],
    # [ "Backup", ["backup"]],
    # [ "Download & Upload", ["download", "upload"]],
    # [ "Download, Upload, & Backup", ["download", "upload", "backup"]],
    # [ "Upload & Backup", ["upload", "backup"]],
    [ "Message", ["message"]],
    [ "Reset", ["reset"]]
])
actionItems.insert(0,[ "Back", ["main"]])

# Message Menu
messageItems = sorted([
    [ "All", "all"],
    [ "New", "new"],
    [ "Recent", "recent"],
    [ "User by Username", "username"],
    [ "User by ID", "id"]
])
messageItems.insert(0,[ "Back", "main"])

# File Type Menu
fileItems = sorted([
    [ "Image", "image"],
    [ "Gallery", "gallery"],
    [ "Performer", "performer"],
    [ "Scene", "scene"],
    [ "Video", "video"],
])
fileItems.insert(0,[ "Back", "main"])

# File Location Menu
locationItems = sorted([
    [ "Local", "local"],
    [ "Google Drive", "google"]
])
locationItems.insert(0,[ "Back", "main"])

settingItems = []

def initialize():
    # print("Initializing Menu")
    global INITIALIZED
    if INITIALIZED:
        # print("Already Initialized, Skipping")
        return
    global settingItems
    # Settings Menu
    settingItems = sorted([
        [ "File Name", settings.FILE_NAME],
        [ "File Path", settings.FILE_PATH],
        [ "Location", settings.LOCATION, ["Local","Google"]],
        [ "Backup", settings.BACKING_UP, ["True","False"]],
        [ "Delete Google", settings.DELETING, ["True","False"]],
        [ "Delete Local", settings.REMOVE_LOCAL, ["True","False"]],
        [ "Hashtag", settings.HASHTAGGING, ["True","False"]],
        [ "Force Backup", settings.BACKING_UP_FORCE, ["True","False"]],
        [ "Force Upload", settings.FORCE_UPLOAD, ["True","False"]],
        [ "Mount Path", settings.MOUNT_PATH],
        [ "Google: Root Folder Path", settings.MOUNT_DRIVE],
        [ "Users Path", settings.USERS_PATH],
        [ "Show Window", settings.SHOW_WINDOW, ["True","False"]],
        [ "Text", settings.TEXT],
        [ "Image", settings.IMAGE],
        [ "Google: Root Folder Name", settings.ROOT_FOLDER],
        [ "Google: Drive Folders", settings.DRIVE_FOLDERS],
        [ "Image Limit", settings.IMAGE_UPLOAD_LIMIT],
        [ "Image Max", settings.IMAGE_UPLOAD_MAX],
        [ "Tweeting", settings.TWEETING, ["True","False"]],
        [ "Debug", settings.DEBUG, ["True","False"]],
        [ "Debug Skip Download", settings.SKIP_DOWNLOAD, ["True","False"]],    
        [ "Create Missing Google Folders", settings.CREATE_MISSING_FOLDERS, ["True","False"]],    
        [ "Verbal", settings.VERBAL, ["True","False"]]    
    ])
    settingItems.insert(0,[ "Back", "main"])
    # print("Initialized Menu")
    INITIALIZED = True

#####################
##### Functions #####
#####################

### Action Menu - file type
def action():
    for item in actionItems:
        print(colorize("[" + str(actionItems.index(item)) + "] ", 'teal') + list(item)[0])
    while True:
        choice = input(">> ")
        try:
            if int(choice) < 0 or int(choice) >= len(actionItems): raise ValueError
            if str(actionItems[int(choice)][0]) == "Back":
                return main()
            elif str(actionItems[int(choice)][0]) == "Reset":
                onlysnarf.remove_local()
            elif str(actionItems[int(choice)][0]) == "Message":
                actionChoice = list(actionItems[int(choice)])[1]
                return finalizeMessage(actionChoice)
            else:
                actionChoice = list(actionItems[int(choice)])[1]
                return finalizeAction(actionChoice)
        except (ValueError, IndexError, KeyboardInterrupt):
            print("Incorrect Index")
        except:
            print(sys.exc_info()[0])
            print("Missing Method") 

### Action Menu - finalize
def finalizeAction(actionChoice):
    for item in fileItems:
        print(colorize("[" + str(fileItems.index(item)) + "] ", 'teal') + list(item)[0])
    while True:
        fileChoice = input(">> ")
        try:
            if int(fileChoice) < 0 or int(fileChoice) >= len(fileItems): raise ValueError
            if str(fileItems[int(fileChoice)][0]) == "Back":
                return action()
            # Call the matching function
            fileChoice = list(fileItems[int(fileChoice)])[1]
            return performAction(actionChoice, fileChoice)
        except (ValueError, IndexError, KeyboardInterrupt):
            print("Incorrect Index")
        except:
            print(sys.exc_info()[0])
            print("Missing Method") 

### Action Menu - perform
def performAction(actionChoice, fileChoice):
    for action in actionChoice:
        try:
            method = getattr(onlysnarf, str(action))
            response = method(fileChoice)
            if response:
                if str(action) == "download":
                    for setting in settingItems:
                        if setting[0] == "File Name":
                            setting[1] = response[0]
                        elif setting[0] == "File Path":
                            setting[1] = response[1]
        except (ValueError, IndexError, KeyboardInterrupt):
            print("Incorrect Index")
        except:
            print(sys.exc_info()[0])
            print("Missing Method") 
    mainMenu()

# Message Menu - finalize
def finalizeMessage(actionChoice):
    for item in messageItems:
        print(colorize("[" + str(messageItems.index(item)) + "] ", 'teal') + list(item)[0])
    while True:
        choice = input(">> ")
        try:
            if int(choice) < 0 or int(choice) >= len(messageItems): raise ValueError
            if str(messageItems[int(choice)][0]) == "Back":
                return action()
            # Call the matching function
            choice = list(messageItems[int(choice)])[1]
            return performMessage(actionChoice, choice)
        except (ValueError, IndexError, KeyboardInterrupt):
            print(sys.exc_info()[0])
            print("Incorrect Index")

# Message Menu - perform
def performMessage(actionChoice, messageChoice):
    for action in actionChoice:
        try:
            method = getattr(onlysnarf, str(action))
            response = method(messageChoice)    
        except (ValueError, IndexError, KeyboardInterrupt):
            print("Incorrect Index")
        except:
            print(sys.exc_info()[0])
            print("Missing Method") 
    mainMenu()    

###########################

### Settings Menu
def set_settings():
    showHeader()
    print(colorize("Set:",'menu'))
    global settingItems
    for item in settingItems:
        print(colorize("[" + str(settingItems.index(item)) + "] ", 'blue') + list(item)[0])
    while True:
        choice = input(">> ")
        try:
            if int(choice) < 0 or int(choice) >= len(settingItems): raise ValueError
            settingChoice = list(settingItems[int(choice)])[0]
            settingValue = list(settingItems[int(choice)])[1]
            if str(settingChoice) == "Back":
                return main()
            elif str(settingChoice) == "File Name":
                settingValue = input("Enter the file name: ")
            elif str(settingChoice) == "File Path":
                settingValue = input("Enter the file path: ")
            elif str(settingChoice) == "Text":
                settingValue = input("Enter the upload text: ")
            elif str(settingChoice) == "Mount Path":
                settingValue = input("Enter the mount path: ")
            elif str(settingChoice) == "Google: Root Folder Path":
                settingValue = input("Enter the drive path (folderName/folderName/...): ")
            elif str(settingChoice) == "Image":
                settingValue = input("Enter the image path: ")
            elif str(settingChoice) == "Google: Root Folder Name":
                settingValue = input("Enter the Google root folder name: ")
            elif str(settingChoice) == "Google: Drive Folders":
                settingValue = input("Enter the Google drive folders (separated by ',', no spaces): ")
                settingValue = settingValue.split(",")
            elif str(settingChoice) == "Image Limit":
                settingValue = input("Enter the image upload limit: ")
            elif str(settingChoice) == "Image Max":
                settingValue = input("Enter the image upload max: ")
            else:
                list_ = list(settingItems[int(choice)][2])
                print(colorize(str(settingChoice)+" =", 'blue'))
                for item in list_:
                    print(colorize("[" + str(list_.index(item)) + "] ", 'pink') + str(item))
                while True:
                    updateChoice = input(">> ")
                    try:
                        if int(updateChoice) < 0 or int(updateChoice) >= len(list(settingItems[int(choice)][2])): raise ValueError
                        settingValue = list_[int(updateChoice)]
                        break
                    except (ValueError, IndexError, KeyboardInterrupt):
                        print("Incorrect Index")
                    except Exception as e:
                        print('What did shnnarf break?')
                        print(e)
                        break
            global UPDATED
            UPDATED = settingChoice
            global UPDATED_TO
            UPDATED_TO = settingValue
            settingItems[int(choice)][1] = settingValue
            settings.update_value(settingChoice, settingValue)
            return set_settings()
        except (ValueError, IndexError, KeyboardInterrupt):
            print("Incorrect Index")
        except:
            print(sys.exc_info()[0])
            return main()

###########################

def colorize(string, color):
    if not color in colors: return string
    return colors[color] + string + '\033[0m'
  
def exit():
    print("Shnarrf?")
    sys.exit(0)

###########################
import atexit
def exit_handler():
    print('Shnnarrrff!')
    exit()
atexit.register(exit_handler)

import signal
def signal_handler(sig, frame):
    print('Shnnnarf?')
    exit()
signal.signal(signal.SIGINT, signal_handler)
###########################

def main():
    showHeader()
    mainMenu()

def mainMenu():
    ### Main Menu
    print(colorize("Select an option:", 'menu'))
    for item in menuItems:
        print(colorize("[" + str(menuItems.index(item)) + "] ", 'blue') + list(item)[0])
    while True:
        choice = input(">> ")
        try:
            if int(choice) < 0 or int(choice) >= len(menuItems): raise ValueError
            # Call the matching function
            method_name = list(menuItems[int(choice)])[1]
            possibles = globals().copy()
            possibles.update(locals())
            method = possibles.get(method_name)
            if method is not None:
                return method()
            else:
                print("Missing Option")    
        except (ValueError, IndexError, KeyboardInterrupt):
            print("Incorrect Index")
            pass

def showHeader():
    os.system('clear')
    # Print some badass ascii art header here !
    print(colorize(header, 'header'))
    print(colorize('version '+version+'\n', 'green'))
    showSettings()

def showSettings():
    print('Settings:')
    for setting in settingItems:
        if str(setting[0]) != "Back":
            print(' - '+setting[0]+' = '+str(setting[1]))
    global UPDATED
    global UPDATED_TO
    if str(UPDATED) != "False":
        print('\nUpdated: '+str(UPDATED)+' -> '+str(UPDATED_TO))
    UPDATED = False
    print('\r')

###########################

if __name__ == "__main__":
    try:
        main_other()
    except:
        # print(sys.exc_info()[0])
        print("Shhhhhnnnnnarf!")
    finally:
        sys.exit(0)

def main_other():
    settings.initialize()
    initialize()
    main()


from crontab import CronTab
from OnlySnarf.settings import SETTINGS as settings
	
def deleteCron(comment):
	cron = findCron(comment)
	cron.remove(cron)  

def deleteAllCrons():
	cron = CronTab(user='root')
	cron.remove_all()  

# use cron.comment to set cron name and find crons
def disableCron(comment):
	# find cron by comment
	cron = findCron(comment)
	if not cron.is_enabled():
	cron.enable(False)

def enableCron(comment):
	# find cron by comment
	cron = findCron(comment)
	if cron.is_enabled():
		print("Warning: Cron already enabled")
		return
	cron.enable()

# i want to be able tocreate crons that will then automatically
# upload a [gallery] from [a random gallery] every day at a time
# so the args need to be able to define what happens when the main gets run
# and this just needs to write a cron that calls onlysnarf with the right args
def createCron(function, args, every="day", atTime="midnight"):
	print("Creating Cron: {}".format(function))
	cron = findCron(function)
	if cron is not None:
		print("Warning: cron already exists")
		return cron
	# add date and timejob.is_valid()  
	# every = "week";"two weeks";"month"
	print("Creating Cron: {}".format(function))
	cron = CronTab(user='root')

	#####
	# args = args.list to string of - in front
	#####
	# "-".join(args)
	args.addToFront(function)

	newCron = cron.new(command="onlysnarf {}".format(args),comment=function);
	
	# figure out date and time and add
	newCron.every().do(job)
	newCron.every(every).at("10:30").do(job)


	if not newCron.is_valid():
		print("Error: Cron not valid")
		return
	#####
	
	for item in cron:  
	    print item
	cron.write()
	print("Created Cron: {}".format(function))

def listCrons():
	cron = CronTab(user='root')
	for job in cron:
	    print job

# cron.find_command("command name")
# cron.find_comment("comment")
# cron.find_time(time schedule)
def findCron(comment):
	cron = CronTab(user='root')
    return cron.find_comment(str(comment)) 

###################
##### Special #####
###################

# greets new subscribers
def greetNewSubcribers():
	pass

# sends messages to users that were queued for a specific time
def sendQueuedMessages():
	pass


# add -scenes to settings to check all scenes data for a scene to release
# check scene data by making a function that checks all the data files and caches it
# for like only 2 or 5 minutes
# the -scenes function runs hourly and checks the folders, forcing the cache to re up date
# so -scenes -force-cache

def checkScenes(comment, function):
	print("Creating Cron: Scenes")
	cron = CronTab(user='root')
	checkScenes = cron.new(command='onlysnarf-menu -scenes');
	checkScenes.hour.every(1)
	for item in cron:  
	    print item
	cron.write()
	print("Created Cron: Scenes")

# create a method to create upload crons that upload standard like an image once a day
# create a method to create upload crons that get input and set cron at specific hour minute every day/week/month

def uploadContent(type=None, minute=None, hour=None):
	print("Creating Cron: Upload")
	if type==None:
		print("Error: Missing Upload Type")
		return
	if minute==None:
		print("Error: Missing Upload Minute")
		return
	if hour==None:
		print("Error: Missing Upload Hour")
		return
	cron = CronTab(user='root')
	createUpload = cron.new(command='onlysnarf-menu -skeetzo -upload {}'.format(type))
	createUpload.minute.on(minute)
	createUpload.hour.on(hour)
	cron.write()
	print("Created Cron: Upload")


#!/usr/bin/python3
# Global Settings
import sys
import os

class Settings:
    def __init__(self):
        pass

    def initialize(self):
        # print("Initializing self...")
        try:
            if self.INITIALIZED:
                # print("Already Initialized, Skipping")
                return
        except:
            self.INITIALIZED = False

        self.DEFAULT_MESSAGE = ":)"

        self.DEBUG = False

        self.SKIP_DOWNLOAD = False

        self.IMAGE_UPLOAD_LIMIT = 6

        self.IMAGE_UPLOAD_MAX = 15

        self.REMOVE_LOCAL = True

        # backup uploaded content
        self.BACKING_UP = False

        self.BACKING_UP_FORCE = False

        # delete uploaded content
        self.DELETING = False
        self.DELETING_FORCED = False
        
        # -video
        # -gallery
        # -image
        # -scene
        self.TYPE = None

        # Twitter hashtags
        self.HASHTAGGING = False

        # -force / ignore upload max wait
        self.FORCE_UPLOAD = False

        # -show -> shows window
        self.SHOW_WINDOW = False

        self.SPECIAL_CRONS = [
            "queuedMessages",
            "greetNew"
        ]

        # -text
        self.TEXT = None

        # -quiet
        self.TWEETING = True

        self.LOCATION = "google"

        # def init(sys.argv):
        self.MOUNT_PATH = None
        self.MOUNT_DRIVE = None
        self.USERS_PATH = "users.json"
        self.CONFIG_PATH = "config.json"
        self.GOOGLE_CREDS_PATH = "google_creds.txt"
        self.SECRET_PATH = "client_secret.json"
        self.WORKING_VIDEO = "video.mp4"

        self.FILE_NAME = None
        self.FILE_PATH = None

        self.THUMBNAILING_PREVIEW = True

        self.IMAGE = None

        self.RECENT_USER_COUNT = 3

        self.DEFAULT_PRICE = "10.00"

        self.FORCE_REDUCTION = False

        self.CREATE_MISSING_FOLDERS = False

        self.VERBAL = False

        self.ROOT_FOLDER = "OnlySnarf"

        self.SKIP_REPAIR = False
        self.SKIP_REDUCE = False
        self.SKIP_THUMBNAIL = False

        self.SKIP_USERS = [
            "6710870",
            
            "5451153",
            "1771880",
            "5057708",
            "7825384",
            "4883991",

            "1633091",
            "3055233"
        ]

        self.DRIVE_FOLDERS = [
            "images",
            "galleries",
            "performers",
            "scenes",
            "videos"
        ]

        self.user_DEFAULT_GREETING = "hi! thanks for subscribing :3 do you have any preferences?"


        # user message delay
        self.DELAY = False

        i = 0
        while i < len(sys.argv):
            if '-image' in str(sys.argv[i]):
                self.TYPE = "image"
            if '-gallery' in str(sys.argv[i]):
                self.TYPE = "gallery"
            if '-video' in str(sys.argv[i]):
                self.TYPE = "video"
            if '-scene' in str(sys.argv[i]):
                self.TYPE = "scene"
            if '-text' in str(sys.argv[i]):
                self.TEXT = str(sys.argv[i+1])
            if '-debug' in str(sys.argv[i]):
                self.DEBUG = True
            if '-verbal' in str(sys.argv[i]):
                self.VERBAL = True
            if '-backup' in str(sys.argv[i]):
                self.BACKING_UP = True
            if '-force-delete' in str(sys.argv[i]):
                self.DELETING_FORCED = True
            if '-show' in str(sys.argv[i]):
                self.SHOW_WINDOW = True
            if '-quiet' in str(sys.argv[i]):
                self.TWEETING = False
            if '-delete' in str(sys.argv[i]):
                self.DELETING = False
            if '-mount-path' in str(sys.argv[i]):
                self.MOUNT_PATH = str(sys.argv[i+1])
            if '-mount-drive' in str(sys.argv[i]):
                self.MOUNT_DRIVE = str(sys.argv[i+1])
            if '-users' in str(sys.argv[i]):
                self.USERS_PATH = str(sys.argv[i+1])
            if '-image' in str(sys.argv[i]):
                self.IMAGE = str(sys.argv[i+1])
            if '-force-upload' in str(sys.argv[i]):
                self.FORCE_UPLOAD = True
            if '-force-reduc' in str(sys.argv[i]):
                self.FORCE_REDUCTION = True
            if '-force-backup' in str(sys.argv[i]):
                self.BACKING_UP_FORCE = True
            if '-delay' in str(sys.argv[i]):
                self.DELAY = True
            if '-image-limit' in str(sys.argv[i]):
                self.IMAGE_UPLOAD_LIMIT = str(sys.argv[i+1])
            if '-image-max' in str(sys.argv[i]):
                self.IMAGE_UPLOAD_MAX = str(sys.argv[i+1])
            if '-create-folders' in str(sys.argv[i]):
                self.CREATE_MISSING_FOLDERS = True
            if '-skip-reduce' in str(sys.argv[i]):
                self.SKIP_REDUCE = True
            if '-skip-repair' in str(sys.argv[i]):
                self.SKIP_REPAIR = True
            if '-skip-thumb' in str(sys.argv[i]):
                self.SKIP_THUMBNAIL = True
            # skeetzo profile
            if '-skeetzo' in str(sys.argv[i]):
                self.VERBAL = True
                self.BACKING_UP = True
                self.TWEETING = False
                self.MOUNT_PATH = "/mnt/apps/onlysnarf"
                self.MOUNT_DRIVE = "Pron/dbot"
            if '-schizo' in str(sys.argv[i]):
                self.SKIP_THUMBNAIL = True
                # self.SKIP_REPAIR = True
                # self.SKIP_REDUCE = True
                self.VERBAL = True
                self.BACKING_UP = True
                self.TWEETING = False
                self.MOUNT_PATH = "/opt/projects/onlysnarf"
                self.MOUNT_DRIVE = "Pron/dbot"
            if '-dbot' in str(sys.argv[i]):
                self.SKIP_THUMBNAIL = True
                # self.SKIP_REPAIR = True
                # self.SKIP_REDUCE = True
                self.VERBAL = True
                self.BACKING_UP = True
                self.TWEETING = False
                self.MOUNT_PATH = "/mnt/dbot/dev/onlysnarf"
                self.MOUNT_DRIVE = "Pron/dbot"
            i += 1
        
        if self.MOUNT_PATH is not None:
            self.CONFIG_PATH = os.path.join(self.MOUNT_PATH, self.CONFIG_PATH)
            self.SECRET_PATH = os.path.join(self.MOUNT_PATH, self.SECRET_PATH)
            self.GOOGLE_CREDS_PATH = os.path.join(self.MOUNT_PATH, self.GOOGLE_CREDS_PATH)
            self.USERS_PATH = os.path.join(self.MOUNT_PATH, self.USERS_PATH)
            self.WORKING_VIDEO = os.path.join(self.MOUNT_PATH, self.WORKING_VIDEO)
        else:
            self.CONFIG_PATH = os.path.join(os.path.dirname(os.path.realpath(__file__)), self.CONFIG_PATH)
            self.SECRET_PATH = os.path.join(os.path.dirname(os.path.realpath(__file__)), self.SECRET_PATH)
            self.GOOGLE_CREDS_PATH = os.path.join(os.path.dirname(os.path.realpath(__file__)), self.GOOGLE_CREDS_PATH)
            self.USERS_PATH = os.path.join(os.path.dirname(os.path.realpath(__file__)), self.USERS_PATH)
            self.WORKING_VIDEO = os.path.join(os.path.dirname(os.path.realpath(__file__)), self.WORKING_VIDEO)

        self.INITIALIZED = True
        # print("Settings Initialized")
    ###################################################

    #####################
    ##### Functions #####
    #####################

    def getTmp(self):
        # mkdir /tmp
        tmp = os.getcwd()
        if self.MOUNT_PATH != None:
            tmp = os.path.join(self.MOUNT_PATH, "tmp")
        else:
            tmp = os.path.join(tmp, "tmp")
        if not os.path.exists(str(tmp)):
            os.mkdir(str(tmp))
        return tmp

    def maybePrint(self, text):
        if str(self.VERBAL) == "True":
            print(text);

    def update_value(self, variable, newValue):
        variable = str(variable).upper().replace(" ","_")
        try:
            # print("Updating: {} = {}".format(variable, newValue))
            setattr(self, variable, newValue)
            # print("Updated: {} = {}".format(variable, getattr(self, variable)))
        except Exception as e:
            print(e)

SETTINGS = Settings()



#!/usr/bin/python
# 2/7/2019 - Skeetzo
# 4/22/2019 - Skeetzo
# setup & update script for config
import os
import sys
import json

CONFIG_FILE = os.path.join(os.path.dirname(os.path.realpath(__file__)),'config.json')
GOOGLE_CREDS = os.path.join(os.path.dirname(os.path.realpath(__file__)),'google_creds.txt')

def createGoogle():
	print("Setting Up Google Creds")
	data = {}
	global GOOGLE_CREDS
	with open(GOOGLE_CREDS, 'w') as outfile:
	    json.dump(data, outfile, indent=4, sort_keys=True)

def createConfig():
	print("Setting up Config")
	data = receiveInputs()
	global CONFIG_FILE
	with open(CONFIG_FILE, 'w') as outfile:
	    json.dump(data, outfile, indent=4, sort_keys=True)

def updateConfig(config):
	print("Updating Config")
	print("(k to keep same)")
	global CONFIG_FILE
	data = receiveInputs()
	for key, value in data.items():
		if value.lower() == "k":
			continue
		config[key] = value
	with open(CONFIG_FILE, 'w') as outfile:
	    json.dump(config, outfile, indent=4, sort_keys=True)

def receiveInputs():
	data = {}
	data['username'] = input('Twitter Username: ')
	data['password'] = input('Twitter Password: ')
	data['images_folder'] = input('Google Drive Folder - Images: ')
	data['galleries_folder'] = input('Google Drive Folder - Galleries: ')
	data['performers_folder'] = input('Google Drive Folder - Performers: ')
	data['scenes_folder'] = input('Google Drive Folder - Scenes: ')
	data['videos_folder'] = input('Google Drive Folder - Videos: ')
	data['posted_folder'] = input('Google Drive Folder - Posted (backup location): ')
	return data

def main():
	global CONFIG_FILE
	try:
		with open(CONFIG_FILE) as config_file:    
			config = json.load(config_file)
		updateConfig(config)
	except FileNotFoundError:
		createConfig()
	finally:
		print('Config Updated')
		sys.exit(0)

if __name__ == "__main__":
	main()